@@ -1,11 +1,6 @@
 package POE::Component::IRC::Constants;
-BEGIN {
-  $POE::Component::IRC::Constants::AUTHORITY = 'cpan:HINRIK';
-}
-BEGIN {
-  $POE::Component::IRC::Constants::VERSION = '6.52';
-}
-
+our $AUTHORITY = 'cpan:HINRIK';
+$POE::Component::IRC::Constants::VERSION = '6.93';
 use strict;
 use warnings FATAL => 'all';
 
