@@ -1,16 +1,11 @@
 package POE::Component::IRC::Qnet::State;
-BEGIN {
-  $POE::Component::IRC::Qnet::State::AUTHORITY = 'cpan:HINRIK';
-}
-BEGIN {
-  $POE::Component::IRC::Qnet::State::VERSION = '6.52';
-}
-
+our $AUTHORITY = 'cpan:HINRIK';
+$POE::Component::IRC::Qnet::State::VERSION = '6.93';
 use strict;
 use warnings FATAL => 'all';
 use Carp;
 use POE;
-use POE::Component::IRC::Common qw(:ALL);
+use IRC::Utils qw(uc_irc normalize_mask parse_user);
 use POE::Component::IRC::Plugin qw(:ALL);
 use base qw(POE::Component::IRC::State POE::Component::IRC::Qnet);
 
@@ -74,11 +69,11 @@ sub _resync_chan {
     my $mapping = $self->isupport('CASEMAPPING');
     my $nickname = $self->nick_name();
     my $flags = '%cunharsft';
-    
+
     for my $channel ( @channels ) {
         next if !$self->is_channel_member( $channel, $nickname );
 
-        my $uchan = u_irc $channel, $mapping;
+        my $uchan = uc_irc $channel, $mapping;
         delete $self->{STATE}->{Chans}->{ $uchan };
         $self->{CHANNEL_SYNCH}->{ $uchan } = { MODE => 0, WHO => 0, BAN => 0, _time => time() };
         $self->{STATE}->{Chans}->{ $uchan } = { Name => $channel, Mode => '' };
@@ -87,7 +82,7 @@ sub _resync_chan {
         $self->yield ( 'mode' => $channel );
         $self->yield ( 'mode' => $channel => 'b');
     }
-    
+
     return;
 }
 
@@ -100,13 +95,13 @@ sub _resync_nick {
     my $user = $info->{User};
     my $host = $info->{Host};
     my $mapping = $self->isupport('CASEMAPPING');
-    my $unick = u_irc $nick, $mapping;
+    my $unick = uc_irc $nick, $mapping;
     my $flags = '%cunharsft';
-    
+
     for my $channel ( @channels ) {
         next if !$self->is_channel_member( $channel, $nick );
-        
-        my $uchan = u_irc $channel, $mapping;
+
+        my $uchan = uc_irc $channel, $mapping;
         $self->yield ( 'sl' => "WHO $nick $flags,102" );
         $self->{STATE}->{Nicks}->{ $unick }->{Nick} = $nick;
         $self->{STATE}->{Nicks}->{ $unick }->{User} = $user;
@@ -115,7 +110,7 @@ sub _resync_nick {
         $self->{STATE}->{Chans}->{ $uchan }->{Nicks}->{ $unick } = '';
         push @{ $self->{NICK_SYNCH}->{ $unick } }, $channel;
     }
-    
+
     return;
 }
 
@@ -134,20 +129,20 @@ sub S_354 {
     my $mapping = $irc->isupport('CASEMAPPING');
     my ($query, $channel, $user, $host, $server, $nick, $status, $auth, $real)
         = @{ ${ $_[2] } };
-    my $unick = u_irc $nick, $mapping;
-    my $uchan = u_irc $channel, $mapping;
-  
+    my $unick = uc_irc $nick, $mapping;
+    my $uchan = uc_irc $channel, $mapping;
+
     $self->{STATE}->{Nicks}->{ $unick }->{Nick} = $nick;
     $self->{STATE}->{Nicks}->{ $unick }->{User} = $user;
     $self->{STATE}->{Nicks}->{ $unick }->{Host} = $host;
     $self->{STATE}->{Nicks}->{ $unick }->{Real} = $real;
     $self->{STATE}->{Nicks}->{ $unick }->{Server} = $server;
     $self->{STATE}->{Nicks}->{ $unick }->{Auth} = $auth if ( $auth );
-    
+
     if ( $auth and defined ( $self->{USER_AUTHED}->{ $unick } ) ) {
         $self->{USER_AUTHED}->{ $unick } = $auth;
     }
-  
+
     if ( $query eq '101' ) {
         my $whatever = '';
         $whatever .= 'o' if $status =~ /\@/;
@@ -161,7 +156,7 @@ sub S_354 {
     if ( $status =~ /\*/ ) {
         $self->{STATE}->{Nicks}->{ $unick }->{IRCop} = 1;
     }
-    
+
     return PCI_EAT_NONE;
 }
 
@@ -170,22 +165,22 @@ sub S_315 {
     my ($self, $irc) = splice @_, 0, 2;
     my $mapping = $irc->isupport('CASEMAPPING');
     my $channel = ${ $_[2] }->[0];
-    my $uchan = u_irc $channel, $mapping;
+    my $uchan = uc_irc $channel, $mapping;
 
     if ( exists $self->{STATE}->{Chans}->{ $uchan } ) {
         if ( $self->_channel_sync($channel, 'WHO' ) ) {
             my $rec = delete $self->{CHANNEL_SYNCH}->{ $uchan };
-            $self->_send_event( 'irc_chan_sync', $channel, time() - $rec->{_time} );
+            $self->send_event_next( 'irc_chan_sync', $channel, time() - $rec->{_time} );
         }
     }
     # it's apparently a nickname
     elsif ( defined $self->{USER_AUTHED}->{ $uchan } ) {
-        $self->_send_event( 'irc_nick_authed', $channel, delete $self->{USER_AUTHED}->{ $uchan } );
+        $self->send_event_next( 'irc_nick_authed', $channel, delete $self->{USER_AUTHED}->{ $uchan } );
     }
     else {
         my $chan = shift @{ $self->{NICK_SYNCH}->{ $uchan } };
         delete $self->{NICK_SYNCH}->{ $uchan } if !@{ $self->{NICK_SYNCH}->{ $uchan } };
-        $self->_send_event( 'irc_nick_sync', $channel, $chan );
+        $self->send_event_next( 'irc_nick_sync', $channel, $chan );
     }
 
     return PCI_EAT_NONE;
@@ -197,11 +192,11 @@ sub S_join {
     my $channel = ${ $_[1] };
 
     my $mapping = $irc->isupport('CASEMAPPING');
-    my $uchan = u_irc $channel, $mapping;
-    my $unick = u_irc $nick, $mapping;
+    my $uchan = uc_irc $channel, $mapping;
+    my $unick = uc_irc $nick, $mapping;
     my $flags = '%cunharsft';
 
-    if ( $unick eq u_irc ( $self->nick_name(), $mapping ) ) {
+    if ( $unick eq uc_irc ( $self->nick_name(), $mapping ) ) {
         delete $self->{STATE}->{Chans}->{ $uchan };
         $self->{CHANNEL_SYNCH}->{ $uchan } = {
             MODE => 0,
@@ -210,7 +205,7 @@ sub S_join {
             _time => time()
         };
         $self->{STATE}->{Chans}->{ $uchan } = { Name => $channel, Mode => '' };
-        
+
         $self->yield ( 'sl' => "WHO $channel $flags,101" );
         $self->yield ( 'mode' => $channel );
         $self->yield ( 'mode' => $channel => 'b');
@@ -223,12 +218,12 @@ sub S_join {
             my $nuser = delete $self->{NETSPLIT}->{Users}->{ $netsplit };
             if ( ( time - $nuser->{stamp} ) < ( 60 * 60 ) ) {
               $self->{STATE}->{Nicks}->{ $unick } = $nuser->{meta};
-              $self->_send_event(irc_nick_sync => $nick, $channel);
+              $self->send_event_next(irc_nick_sync => $nick, $channel);
             }
             return PCI_EAT_NONE;
         }
         if ( exists $self->{STATE}->{Nicks}->{ $unick }->{Real} ) {
-            $self->_send_event(irc_nick_sync => $nick, $channel);
+            $self->send_event_next(irc_nick_sync => $nick, $channel);
             return PCI_EAT_NONE;
         }
         $self->yield ( 'sl' => "WHO $nick $flags,102" );
@@ -248,26 +243,26 @@ sub S_chan_mode {
     my $mapping = $irc->isupport('CASEMAPPING');
     pop @_;
     my $who = ${ $_[0] };
-    my $source = u_irc ( ( split /!/, $who )[0], $mapping );
+    my $source = uc_irc ( ( split /!/, $who )[0], $mapping );
     my $mode = ${ $_[2] };
     my $arg = defined $_[3] ? ${ $_[3] } : '';
-    my $uarg = u_irc $arg, $mapping;
-    
+    my $uarg = uc_irc $arg, $mapping;
+
     return PCI_EAT_NONE if $source !~ /^[Q]$/ || $mode !~ /[ov]/;
-    
+
     if ( !$self->is_nick_authed($arg) && !$self->{USER_AUTHED}->{ $uarg } ) {
        $self->{USER_AUTHED}->{ $uarg } = 0;
        $self->yield ( 'sl' => "WHO $arg " . '%cunharsft,102' );
     }
-    
+
     return PCI_EAT_NONE;
 }
 
 sub S_part {
     my ($self, $irc) = splice @_, 0, 2;
     my $mapping = $irc->isupport('CASEMAPPING');
-    my $nick = u_irc ( ( split /!/, ${ $_[0] } )[0], $mapping );
-    my $channel = u_irc ${ $_[1] }, $mapping;
+    my $nick = uc_irc ( ( split /!/, ${ $_[0] } )[0], $mapping );
+    my $channel = uc_irc ${ $_[1] }, $mapping;
     if ( ref $_[2] eq 'ARRAY' ) {
         push @{ $_[-1] }, '', $self->is_nick_authed( $nick );
     }
@@ -275,7 +270,7 @@ sub S_part {
         push @{ $_[-1] }, $self->is_nick_authed( $nick );
     }
 
-    if ( $nick eq u_irc ( $self->nick_name(), $mapping ) ) {
+    if ( $nick eq uc_irc ( $self->nick_name(), $mapping ) ) {
         delete $self->{STATE}->{Nicks}->{ $nick }->{CHANS}->{ $channel };
         delete $self->{STATE}->{Chans}->{ $channel }->{Nicks}->{ $nick };
         for my $member ( keys %{ $self->{STATE}->{Chans}->{ $channel }->{Nicks} } ) {
@@ -293,7 +288,7 @@ sub S_part {
                 delete $self->{STATE}->{Nicks}->{ $nick };
         }
     }
-    
+
     return PCI_EAT_NONE;
 }
 
@@ -304,13 +299,13 @@ sub S_quit {
     my $msg = ${ $_[1] };
     push @{ $_[2] }, [ $self->nick_channels( $nick ) ];
     push @{ $_[2] }, $self->is_nick_authed( $nick );
-    my $unick = u_irc $nick, $mapping;
+    my $unick = uc_irc $nick, $mapping;
     my $netsplit = 0;
 
     # Check if it is a netsplit
     $netsplit = 1 if _is_netsplit( $msg );
 
-    if ( $unick eq u_irc ( $self->nick_name(), $mapping ) ) {
+    if ( $unick eq uc_irc ( $self->nick_name(), $mapping ) ) {
         delete $self->{STATE};
     }
     else {
@@ -324,7 +319,7 @@ sub S_quit {
              { meta => $nickstate, stamp => time };
         }
     }
-    
+
     return PCI_EAT_NONE;
 }
 
@@ -339,13 +334,13 @@ sub S_kick {
     my $mapping = $irc->isupport('CASEMAPPING');
     my $channel = ${ $_[1] };
     my $nick = ${ $_[2] };
-    my $unick = u_irc $nick, $mapping;
-    my $uchan = u_irc $channel, $mapping;
+    my $unick = uc_irc $nick, $mapping;
+    my $uchan = uc_irc $channel, $mapping;
 
     push @{ $_[-1] }, $self->nick_long_form( $nick );
     push @{ $_[-1] }, $self->is_nick_authed( $nick );
 
-    if ( $unick eq u_irc ( $self->nick_name(), $mapping ) ) {
+    if ( $unick eq uc_irc ( $self->nick_name(), $mapping ) ) {
         delete $self->{STATE}->{Nicks}->{ $unick }->{CHANS}->{ $uchan };
         delete $self->{STATE}->{Chans}->{ $uchan }->{Nicks}->{ $unick };
         for my $member ( keys %{ $self->{STATE}->{Chans}->{ $uchan }->{Nicks} } ) {
@@ -363,15 +358,15 @@ sub S_kick {
             delete $self->{STATE}->{Nicks}->{ $unick };
         }
     }
-    
+
     return PCI_EAT_NONE;
 }
 
 sub is_nick_authed {
     my ($self, $nick) = @_;
     my $mapping = $self->isupport('CASEMAPPING');
-    my $unick = u_irc $nick, $mapping;
-    
+    my $unick = uc_irc $nick, $mapping;
+
     return if !$self->_nick_exists($nick);
 
     if (defined $self->{STATE}->{Nicks}->{ $unick }->{Auth}) {
@@ -384,8 +379,8 @@ sub is_nick_authed {
 sub find_auth_nicks {
     my ($self, $auth, $channel) = @_;
     my $mapping = $self->isupport('CASEMAPPING');
-    my $uchan = u_irc $channel, $mapping;
-    
+    my $uchan = uc_irc $channel, $mapping;
+
     return if !$self->_channel_exists($channel);
     my @results;
 
@@ -396,12 +391,12 @@ sub find_auth_nicks {
         }
     }
 
-    return @results; 
+    return @results;
 }
 
 sub ban_mask {
     my ($self, $channel, $mask) = @_;
-    $mask = parse_ban_mask($mask);
+    $mask = normalize_mask($mask);
     my $mapping = $self->isupport('CASEMAPPING');
     my @result;
 
@@ -415,15 +410,15 @@ sub ban_mask {
 
     for my $nick ( $self->channel_list($channel) ) {
         my $long_form = $self->nick_long_form($nick);
-        
-        if ( u_irc ( $long_form ) =~ /^$mask$/ ) {
+
+        if ( uc_irc ( $long_form ) =~ /^$mask$/ ) {
             push @result, $nick;
             next;
         }
 
         if ( my $auth = $self->is_nick_authed( $nick ) ) {
             $long_form =~ s/\@(.+)$/\@$auth.users.quakenet.org/;
-            push @result, $nick if u_irc ( $long_form ) =~ /^$mask$/;
+            push @result, $nick if uc_irc ( $long_form ) =~ /^$mask$/;
         }
     }
 
@@ -457,7 +452,7 @@ for Quakenet with nickname and channel tracking
  my @channels = ( '#Blah', '#Foo', '#Bar' );
 
  # We create a new PoCo-IRC object and component.
- my $irc = POE::Component::IRC::Qnet::State->spawn( 
+ my $irc = POE::Component::IRC::Qnet::State->spawn(
      nick => $nickname,
      server => $ircserver,
      port => $port,
@@ -481,7 +476,7 @@ for Quakenet with nickname and channel tracking
      my $irc_session = $heap->{irc}->session_id();
      $kernel->post( $irc_session => register => 'all' );
      $kernel->post( $irc_session => connect => { } );
-     
+
      return;
  }
 
@@ -532,7 +527,7 @@ for Quakenet with nickname and channel tracking
              push ( @output, "'$arg'" );
          }
      }
-     
+
      print join ' ', @output, "\n";
      return 0;
  }
@@ -600,7 +595,7 @@ event for each of the given channels (assuming that nick is on each of those cha
 
 =back
 
-=head1 OUTPUT
+=head1 OUTPUT EVENTS
 
 This module returns one additional event over and above the usual events:
 
